<?php

namespace Litecrm\Call\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecrm\Call\Http\Requests\DbuploadRequest;
use Litecrm\Call\Interfaces\DbuploadRepositoryInterface;
use Litecrm\Call\Models\Dbupload;

/**
 * Resource controller class for dbupload.
 */
class DbuploadResourceController extends BaseController
{

    /**
     * Initialize dbupload resource controller.
     *
     * @param type DbuploadRepositoryInterface $dbupload
     *
     * @return null
     */
    public function __construct(DbuploadRepositoryInterface $dbupload)
    {
        parent::__construct();
        $this->repository = $dbupload;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecrm\Call\Repositories\Criteria\DbuploadResourceCriteria::class);
    }

    /**
     * Display a list of dbupload.
     *
     * @return Response
     */
    public function index(DbuploadRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecrm\Call\Repositories\Presenter\DbuploadPresenter::class)
                ->$function();
        }

        $dbuploads = $this->repository->paginate();

        return $this->response->title(trans('call::dbupload.names'))
            ->view('call::dbupload.index', true)
            ->data(compact('dbuploads'))
            ->output();
    }

    /**
     * Display dbupload.
     *
     * @param Request $request
     * @param Model   $dbupload
     *
     * @return Response
     */
    public function show(DbuploadRequest $request, Dbupload $dbupload)
    {

        if ($dbupload->exists) {
            $view = 'call::dbupload.show';
        } else {
            $view = 'call::dbupload.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('call::dbupload.name'))
            ->data(compact('dbupload'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new dbupload.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DbuploadRequest $request)
    {

        $dbupload = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('call::dbupload.name')) 
            ->view('call::dbupload.create', true) 
            ->data(compact('dbupload'))
            ->output();
    }

    /**
     * Create new dbupload.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DbuploadRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $dbupload                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('call::dbupload.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('call/dbupload/' . $dbupload->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/call/dbupload'))
                ->redirect();
        }

    }

    /**
     * Show dbupload for editing.
     *
     * @param Request $request
     * @param Model   $dbupload
     *
     * @return Response
     */
    public function edit(DbuploadRequest $request, Dbupload $dbupload)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('call::dbupload.name'))
            ->view('call::dbupload.edit', true)
            ->data(compact('dbupload'))
            ->output();
    }

    /**
     * Update the dbupload.
     *
     * @param Request $request
     * @param Model   $dbupload
     *
     * @return Response
     */
    public function update(DbuploadRequest $request, Dbupload $dbupload)
    {
        try {
            $attributes = $request->all();

            $dbupload->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('call::dbupload.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('call/dbupload/' . $dbupload->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('call/dbupload/' . $dbupload->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the dbupload.
     *
     * @param Model   $dbupload
     *
     * @return Response
     */
    public function destroy(DbuploadRequest $request, Dbupload $dbupload)
    {
        try {

            $dbupload->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('call::dbupload.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('call/dbupload/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('call/dbupload/' . $dbupload->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple dbupload.
     *
     * @param Model   $dbupload
     *
     * @return Response
     */
    public function delete(DbuploadRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('call::dbupload.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('call/dbupload'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/call/dbupload'))
                ->redirect();
        }

    }

    /**
     * Restore deleted dbuploads.
     *
     * @param Model   $dbupload
     *
     * @return Response
     */
    public function restore(DbuploadRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('call::dbupload.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/call/dbupload'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/call/dbupload/'))
                ->redirect();
        }

    }

}
